package com.cultural.heritage.listener;

import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.MqConstant;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.model.entity.Coupon;
import com.cultural.heritage.service.good.CouponService;
import com.cultural.heritage.utils.MultiDelayMessage;
import jakarta.annotation.Resource;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.stereotype.Component;

@Component
public class CouponStatusListener {


    @Resource
    private CouponService couponService;


    @Resource
    private RabbitTemplate rabbitTemplate;



    @RabbitListener(bindings = @QueueBinding(
            value = @Queue(MqConstant.DELAY_COUPON_QUEUE),
            exchange = @Exchange(name = MqConstant.DELAY_EXCHANGE, delayed = "true"),
            key = MqConstant.DELAY_COUPON_ROUTING_KEY
    ))
    public void listenDelayMessage(MultiDelayMessage<Coupon> msg) {
        System.out.println("\n\n\n\n\nCouponStatusListener.listenerDelayMessage msg-------------------------------->：" + msg);

        // 1.获取消息中的优惠券id
        Coupon sourceCoupon = msg.getData();
        Long couponId = sourceCoupon.getId();
        // 2.判断优惠券是否存在
        Coupon targetCoupon = couponService.getById(couponId);
        if (targetCoupon == null) {
            return ;
        }
        // 3.判断日期是否被更新过
        if (!sourceCoupon.getEndTime().equals(targetCoupon.getEndTime())) {
            return ;
        }
        // 3.优惠券未到截止日期，判断是否还有剩余延时时间
        if (msg.hasNextDelay()) {
            // 有延迟时间，需要重发延迟消息，先获取延迟时间的int值
            // 发送延时消息
            int delayValue = msg.removeNextDelay().intValue();
            rabbitTemplate.convertAndSend(MqConstant.DELAY_EXCHANGE,
                    MqConstant.DELAY_COUPON_ROUTING_KEY, msg, message -> {
                        // 添加延迟消息属性
                        message.getMessageProperties().setDelay(delayValue * 1000);
                        return message;
                    });
            return ;
        }
        // 4.更新优惠券状态
        UpdateWrapper<Coupon> updateWrapper = new UpdateWrapper<>();
        updateWrapper.eq("id", couponId).set("status", "已过期");
        boolean update = couponService.update(updateWrapper);
        ThrowUtils.throwIf(!update, ErrorCode.OPERATION_ERROR, "优惠券状态更新失败");

    }


}
