package com.cultural.heritage.model.dto.clothes;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 服装更新请求体
 */
@Data
@Schema(description = "服装更新请求体", requiredProperties = {"id", "name", "category", "price", "image", "period", "isShelves"})
public class ClothesUpdateRequest implements Serializable {

    /**
     * 服装id
     */
    @Schema(description = "服装id(id > 0)", example = "17")
    private Long id;

    /**
     * 服装名称
     */
    @Schema(description = "服装名称", example = "汉服")
    private String name;

    /**
     * 类别id
     */
    @Schema(description = "服装类别id", example = "1")
    private Long categoryId;

    /**
     * 价格/天
     */
    @Schema(description = "价格/天", example = "100.00")
    private BigDecimal price;

    /**
     * 最大租赁天数
     */
    @Schema(description = "最大租赁天数", example = "30")
    private Integer period;

    /**
     * 服装图片
     */
    @Schema(description = "服装图片", example = "https://xxx.jpg")
    private String image;

    /**
     * 富文本
     */
    @Schema(description = "服装详情（富文本）", example = "<p>详细描述</p>")
    private String richText;

    /**
     * 是否上架
     */
    @Schema(description = "是否上架(1:上架;0:下架)", example = "1")
    private Integer isShelves;

    @Serial
    private static final long serialVersionUID = 1L;
}
