package com.cultural.heritage.service.good.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.mapper.CategoryMapper;
import com.cultural.heritage.model.entity.Category;
import com.cultural.heritage.service.good.CategoryService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

@Service
public class CategoryServiceImpl extends ServiceImpl<CategoryMapper, Category> implements CategoryService {

    @Override
    public Category getCategoryById(Long id) {
        QueryWrapper<Category> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("id", id);
        Category category = this.baseMapper.selectOne(queryWrapper);
        if (category == null) {
            throw new BusinessException(ErrorCode.NOT_FOUND_ERROR);
        }
        return category;
    }



    @Override
    public void validCategory(Category category, boolean add) {
        String typeName = category.getTypeName();
        String typeUrl = category.getTypeUrl();
        ThrowUtils.throwIf(StringUtils.isBlank(typeName), ErrorCode.PARAMS_ERROR);
        QueryWrapper<Category> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("typeName", typeName);
        // 创建时，参数不能为空
        if (add) {
            Long count = this.baseMapper.selectCount(queryWrapper);
            ThrowUtils.throwIf(count > 0, ErrorCode.PARAMS_ERROR, "类别名称不可重复");
        } else {
            Long id = category.getId();
            queryWrapper.ne("id", id);
            Long count = this.baseMapper.selectCount(queryWrapper);
            ThrowUtils.throwIf(count > 0, ErrorCode.PARAMS_ERROR, "类别名称已存在");
        }
        // 有参数则校验
        if (StringUtils.isBlank(typeUrl)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "请上传图片或填写商品详情");
        }

    }

}
