package com.cultural.heritage.service.user;

import cn.binarywang.wx.miniapp.bean.WxMaJscode2SessionResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.cultural.heritage.model.dto.user.UserQueryRequest;
import com.cultural.heritage.model.entity.User;
import com.cultural.heritage.model.vo.user.UserVO;
import jakarta.servlet.http.HttpServletRequest;

import java.util.List;

public interface UserService extends IService<User> {

    /**
     * 用户登录
     * @param userAccount 用户账户
     * @param userPassword 用户密码
     */
    UserVO userLogin(String userAccount, String userPassword, HttpServletRequest request);


    /**
     * 获取用户信息
     */
    UserVO getUserVO(User user);


    /**
     * 校验用户信息
     */
    void validUser(User user, boolean update);


    /**
     * 用户退出
     * @return 是否退出成功
     */
    boolean userLogout(HttpServletRequest request);

    /**
     * 获取当前登录用户
     */
    User getLoginUser(HttpServletRequest request);

    /**
     * 获取查询条件
     */
    QueryWrapper<User> getQueryWrapper(UserQueryRequest userQueryRequest);


    /**
     * 获取脱敏的用户信息
     */
    List<UserVO> getUserVO(List<User> userList);


    /**
     * 用户登录（微信小程序）
     */
    UserVO userLoginByMpOpen(WxMaJscode2SessionResult sessionInfo, HttpServletRequest request);


    /**
     * 用户添加（扣除）积分
     */
    void addOrSubUserPoints(Long userId, boolean isAdd, Integer points);
}
