package com.cultural.heritage.utils;

import java.lang.reflect.Method;
import java.util.*;

public class DynamicSort {

    public static <T> List<T> sortList(List<T> sourceList, String sortField, String sortOrder) {
        // 使用 Comparator 来定义排序逻辑
        Comparator<T> comparator = (T o1, T o2) -> {
            try {
                // 通过反射获取字段的 getter 方法
                Method getter = o1.getClass().getMethod("get" + capitalize(sortField));
                Comparable value1 = (Comparable) getter.invoke(o1);
                Comparable value2 = (Comparable) getter.invoke(o2);

                // 根据 sortOrder 决定是升序还是降序
                if ("ascend".equalsIgnoreCase(sortOrder)) {
                    return value1.compareTo(value2);
                } else {
                    return value2.compareTo(value1);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
            return 0;
        };

        // 使用 Collections.sort() 排序
        sourceList.sort(comparator);
        return sourceList;
    }

    // 将字段名首字母大写，生成 getter 方法的名称
    private static String capitalize(String str) {
        if (str == null || str.isEmpty()) {
            return str;
        }
        return str.substring(0, 1).toUpperCase() + str.substring(1);
    }


}
